#include <stdio.h>

void vcl_stuff(void)
{
  printf("Placeholder for a file with strange name\n");
}
